@@ -21,10 +21,8 @@ import authMiddleware from './lib/auth-middleware';
 import logger from './lib/logger';
 import KubeConnector from './connectors/kube';
 import ClusterModel from './models/cluster';
-import PlacementModel from './models/placement';
 import GenericModel from './models/generic';
 import ComplianceModel from './models/compliance';
-import SAModel from './models/sa';
 import schema from './schema';
 import config from '../../config';
 
@@ -61,10 +59,8 @@ const apolloServer = new ApolloServer({
     return {
       req,
       clusterModel: new ClusterModel({ kubeConnector }),
-      PlacementModel: new PlacementModel({ kubeConnector }),
       genericModel: new GenericModel({ kubeConnector }),
       complianceModel: new ComplianceModel({ kubeConnector }),
-      saModel: new SAModel({ kubeConnector, req }),
     };
   },
 });
